AppLocalizationsKm class

The translations for Khmer Central Khmer (km).

Inheritance

Constructors

AppLocalizationsKm([String locale = 'km'])

Properties

hashCode int
The hash code for this object.
no setterinherited
justNow String
No description provided for @justNow.
no setteroverride
localeName String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unknownDate String
No description provided for @unknownDate.
no setteroverride
unknownTime String
No description provided for @unknownTime.
no setteroverride

Methods

daysAgo(Object days) String
No description provided for @daysAgo.
override
hoursAgo(Object hours) String
No description provided for @hoursAgo.
override
minutesAgo(Object minutes) String
No description provided for @minutesAgo.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited